@@ -30,8 +30,11 @@ handler.setFormatter(
     logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
 logger.addHandler(handler)
 
-TEMPLATES_DIR_PATH = os.path.abspath(
-    os.path.join('.', 'templates'))
+if hasattr(settings, 'TEMPLATES'):
+    TEMPLATES_DIR_PATH = settings.TEMPLATES[0]['DIRS'][0]
+else:
+    TEMPLATES_DIR_PATH = os.path.abspath(
+        os.path.join('.', 'templates'))
 
 class Command(BaseCommand):
 
